@@ -38,6 +38,14 @@ class SSHClient(object):
         self.__ssh = None
         self.__sftp = None
 
+    @property
+    def ip(self):
+        return self.__ip
+
+    @property
+    def port(self):
+        return self.__port
+
     @property
     def is_sshable(self):
         ssh = paramiko.SSHClient()
@@ -89,7 +97,7 @@ class SSHClient(object):
             log.info(f"{self.__ip}:{self.__port} | ssh connect successfully.")
             return True
         except Exception as e:
-            log.error(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
+            log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
             return False
 
     def reconnect(self):
@@ -155,7 +163,7 @@ class SSHClient(object):
                     raise RuntimeError("ssh transport is not active and failed to reconnect.")
             return self._exec(cmd,promt_response,timeout)
         except Exception as e:
-            log.error(f"when run cmd: {cmd}, meets exception.", exc_info=True)
+            log.warning(f"when run cmd: {cmd}, meets exception.", exc_info=True)
             return ExecResult(1, "", str(e))
 
     def _scp_to_remote(self, local_path, remote_path):
@@ -168,7 +176,7 @@ class SSHClient(object):
                 f" {self.__ip}:{self.__port} | Success to copy file from local {local_path} to remote host{remote_path}: OK.")
             return True
         else:
-            log.error(
+            log.warning(
                 f" {self.__ip}:{self.__port} | failed to copy file from local {local_path} to remote host{remote_path}:Error.")
             return False
 
@@ -181,7 +189,7 @@ class SSHClient(object):
                 self.__sftp = self.__ssh.open_sftp()
             return self._scp_to_remote(local_path, remote_path)
         except Exception:
-            log.error(f"when scp from local {local_path} to remote {remote_path}, meets exception.", exc_info=True)
+            log.warning(f"when scp from local {local_path} to remote {remote_path}, meets exception.", exc_info=True)
             return False
 
     def _scp_file_to_local(self, remote_path, local_path):
@@ -203,7 +211,7 @@ class SSHClient(object):
                 self.__sftp = self.__ssh.open_sftp()
             return self._scp_file_to_local(remote_path, local_path)
         except Exception:
-            log.error(f"when scp from remote {remote_path} to local {local_path}, meets exception.", exc_info=True)
+            log.warning(f"when scp from remote {remote_path} to local {local_path}, meets exception.", exc_info=True)
             return False
 
     def __del__(self):
